@@ -10,6 +10,7 @@ except ImportError:
     pass
 
 from rich.progress import Progress
+from rich.prompt import Confirm
 
 from .console import console
 
@@ -23,7 +24,7 @@ def sam_to_name_labeled_fastq(sample, in_file, out_file):
             new_sam = True
 
     if new_sam:
-        console.log(f"[green]{sample}[/green]: sam is headerless, adding a fake one")
+        console.print(f"[green]{sample}[/green]: sam is headerless, adding a fake one")
         sam_file = fake_header_add(in_file)
     else:
         sam_file = in_file
@@ -177,59 +178,57 @@ def fake_header_add(in_file):
 """
     # TODO: change to with statement
     f = tempfile.NamedTemporaryFile(delete=False, dir=Path.cwd())
-    # print(f'copying new tmp sam to {f.name}')
     f.write((bytes(fake_header, encoding="utf-8")))
     f.flush()
 
-    subprocess.run(["cat", in_file], stdout=f)
-
-    # #python implementation
-    # with open(in_file, 'r') as sam_file:
-    #     for line in sam_file:
-    #         f.write(bytes(line, encoding='utf-8'))
-    #    #f.write(bytes(sam_file.read()), encoding='utf-8')
+    with open(in_file, "r") as sam_file:
+        for line in sam_file:
+            f.write(bytes(line, encoding="utf-8"))
 
     f.close()
     return f.name
 
 
-def single_cell_process(sample, f, sourcedir, cli_args, status):
+def single_cell_process(
+    sample,
+    f,
+    pipeline,
+    output,
+    error,
+    minimum_length,
+    length,
+    upstream_adapter,
+    downstream_adapter,
+    threads,
+    verbose,
+    status,
+):
 
-    error_rate = cli_args["extract"]["error_rate"]
-    threads = cli_args["main"]["threads"]
-    barcode_length_min = 10
-    barcode_length = cli_args["extract"]["barcode_length"]
-    upstream_adapter = cli_args["extract"]["upstream_adapter"]
-    downstream_adapter = cli_args["extract"]["downstream_adapter"]
     adapter_string = f"-g {upstream_adapter} -a {downstream_adapter}"
-
     input_file = f
-    pipeline_dir = Path(cli_args["main"]["pipelinedir"])
-    fastq_out = pipeline_dir / f"{sample}.cell_record_labeled.fastq"
-    output_file = pipeline_dir / f"{sample}.cell_record_labeled.barcode.fastq"
-    tsv_out = (
-        Path(cli_args["main"]["outdir"]) / f"{sample}.cell_record_labeled.barcode.tsv"
-    )
+    fastq_out = pipeline / f"{sample}.cell_record_labeled.fastq"
+    output_file = pipeline / f"{sample}.cell_record_labeled.barcode.fastq"
+    tsv_out = output / f"{sample}.cell_record_labeled.barcode.tsv"
 
     if not fastq_out.is_file():
-        console.log(f"[green]{sample}[/green]: converting sam to labeled fastq")
+        console.print(f"[green]{sample}[/green]: converting sam to labeled fastq")
         status.stop()
         sam_to_name_labeled_fastq(sample, input_file, fastq_out)
         status.start()
     else:
-        console.log(
+        console.print(
             f"[green]{sample}[/green]: skipping sam to labeled fastq conversion"
         )
 
     if not output_file.is_file():
 
-        console.log(f"[green]{sample}[/green]: extracting barcodes")
+        console.print(f"[green]{sample}[/green]: extracting barcodes")
 
         command = f"cutadapt \
-            -e {error_rate} \
+            -e {error} \
             -j {threads} \
-            --minimum-length={barcode_length_min} \
-            --maximum-length={barcode_length} \
+            --minimum-length={minimum_length} \
+            --maximum-length={length} \
             --max-n=0 \
             --trimmed-only {adapter_string} \
             -n 2 \
@@ -244,45 +243,74 @@ def single_cell_process(sample, f, sourcedir, cli_args, status):
             universal_newlines=True,
         )
 
-        if cli_args["main"]["verbose"]:
+        if verbose:
             console.print("[yellow]CUTADAPT OUTPUT:")
             console.print(p.stdout)
 
     if not tsv_out.is_file():
-        console.log(f"[green]{sample}[/green]: converting labeled fastq to tsv")
+        console.print(f"[green]{sample}[/green]: converting labeled fastq to tsv")
         labeled_fastq_to_tsv(output_file, tsv_out)
 
     else:
-        console.log(
+        console.print(
             f"[green]{sample}[/green]: skipping labeled fastq to tsv conversion"
         )
 
 
-def single_cell(sourcedir, cli_args):
+def single_cell(
+    input,
+    pipeline,
+    output,
+    error,
+    minimum_length,
+    length,
+    upstream_adapter,
+    downstream_adapter,
+    threads,
+    verbose,
+):
+    for d in [pipeline, output]:
+        d.mkdir(exist_ok=True)
 
-    console.rule("SINGLE CELL MODE", align="center", style="red")
-    print()
+    # TODO: raise error if can't get sample name
+    sam_files = {f.name.split(".")[0]: f for f in input.iterdir()}
 
-    sam_files = [f for f in sourcedir.iterdir()]
-
-    for f in sam_files:
+    for f in sam_files.values():
 
         ext = f.suffix
 
         if ext != ".sam":
             raise ValueError("There is a non sam file in the provided input directory:")
 
-    for f in sam_files:
+    console.print(f"[b cyan]Samples[/]: {', '.join(sorted(sam_files.keys()))}\n")
 
-        sample = f.name.split(".")[0]
+    if not Confirm.ask("Continue with these samples?"):
+        sys.exit()
+
+    for sample, f in sam_files.items():
+
+        print()
+        console.print(f"──────────────── {sample} ───────────────────", style="dim")
 
         with console.status(
-            f"Processing sample: [green]{sample}[/green]", spinner="dots12"
+            f"Processing sample: [green]{sample}[/green]\r\n",
+            spinner="dots12",
         ) as status:
-            single_cell_process(sample, f, sourcedir, cli_args, status)
-
-        console.log(f"[green]{sample}[/green]: processing completed")
-        console.rule()
+            single_cell_process(
+                sample,
+                f,
+                pipeline,
+                output,
+                error,
+                minimum_length,
+                length,
+                upstream_adapter,
+                downstream_adapter,
+                threads,
+                verbose,
+                status,
+            )
+        console.print(f"[green]{sample}[/green]: processing completed")
 
     console.print("\n[green]FINISHED!")
     sys.exit()
